@@ -917,7 +917,9 @@ class DiffusionAPI(APIMixin):
         class _:
             def __init__(self, api: DiffusionAPI):
                 self.api = api
+                self.m_ctrl = api.m.control_model
                 self.m_cond = api.m.condition_model
+                api.m.control_model = None
                 api.m.condition_model = api.cond_model
 
             def __enter__(self) -> nn.Module:
@@ -929,6 +931,7 @@ class DiffusionAPI(APIMixin):
                 return Wrapper(self.api.m)
 
             def __exit__(self, exc_type: Any, exc_val: Any, exc_tb: Any) -> None:
+                self.api.m.control_model = self.m_ctrl
                 self.api.m.condition_model = self.m_cond
 
         return _(self)
@@ -1280,6 +1283,7 @@ class ControlledDiffusionAPI(DiffusionAPI):
         self.weights = {}
         self.annotators = {}
         self.num_pool = num_pool
+        self.control_model = self.m.control_model
 
     def to(
         self,
@@ -1381,6 +1385,12 @@ class ControlledDiffusionAPI(DiffusionAPI):
             out = np.repeat(out, 3, axis=2)
         return out
 
+    def enable_control(self) -> None:
+        self.m.control_model = self.control_model
+
+    def disable_control(self) -> None:
+        self.m.control_model = None
+
 
 def _ldm(
     model: str,
